#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-static
version:              3.1.9
visibility:           public
id:                   wai-app-static-3.1.9-DUP3a3yYDBK3H5ew2G3hXQ
key:                  wai-app-static-3.1.9-DUP3a3yYDBK3H5ew2G3hXQ
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  df161572fb2727f9a649b027df05d76f
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-app-static-3.1.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-app-static-3.1.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-app-static-3.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-static
hs-libraries:         HSwai-app-static-3.1.9-DUP3a3yYDBK3H5ew2G3hXQ
depends:
    base-4.18.2.1 blaze-html-0.9.2.0-3AC4Y0zpDZCFJLvQyYdeIq
    blaze-markup-0.8.3.0-Emc5r8tAAB5AI1Qfoo7UW6 bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.4-A29aWfOF6sn3Zn8WH7qhgd
    directory-1.3.8.5 file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filepath-1.4.300.1 http-date-0.0.11-77oXsSFhQo0C5jWurS4AfD
    http-types-0.12.4-DSeS6XawuaoHvAFQRL0WJy
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    mime-types-0.1.2.1-1xtxegTvlKyFu1aTXaUpBN
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    optparse-applicative-0.18.1.0-3v5eR4uFUl73jY5cYl6vP5
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-C4WM6snAxnMGmhnzvxcj0k
    unordered-containers-0.2.20.1-A7v2mkdOMedFLrtoUSJIsH
    wai-3.2.4-A7ZXrbgUb6vIgHDmXWwKPS
    wai-extra-3.1.18-EwwI8cznofHFLvxbGTyi3T
    warp-3.4.0-62SQvj24iYn4Yh3QXOSdit
    zlib-0.7.1.0-KJOtboaWcInIg9F8dRf9sX

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

